Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorsgiehl <stefan@piwik.org>2013-08-02 17:26:19 +0400
committersgiehl <stefan@piwik.org>2013-08-02 17:26:19 +0400
commit54e0234ab1a1865d1d2aebd1aa59dc667b9f29b5 (patch)
treeae0892aa1ee5daf87490747cec97abd2e9e5355c /core/Archive
parentf45ae6c867316df331bbedbf69104ce867fbdf48 (diff)
fixed more doc blocks and namespaces
Diffstat (limited to 'core/Archive')
-rw-r--r--core/Archive/DataCollection.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/core/Archive/DataCollection.php b/core/Archive/DataCollection.php
index 65b33a3765..61499219d4 100644
--- a/core/Archive/DataCollection.php
+++ b/core/Archive/DataCollection.php
@@ -93,7 +93,7 @@ class DataCollection
* '2012-02-01,2012-02-28' => new Period(...),
* )
*
- * @var array
+ * @var \Piwik\Period[]
*/
private $periods;
@@ -103,7 +103,7 @@ class DataCollection
* @param array $dataNames @see $this->dataNames
* @param string $dataType @see $this->dataType
* @param array $sitesId @see $this->sitesId
- * @param array $periods @see $this->periods
+ * @param \Piwik\Period[] $periods @see $this->periods
* @param array $defaultRow @see $this->defaultRow
*/
public function __construct($dataNames, $dataType, $sitesId, $periods, $defaultRow = null)
@@ -228,13 +228,13 @@ class DataCollection
* by the metadata specified here.
*
* Eg, array('site' => 'idSite', 'period' => 'Date')
* @param int $idSubtable The subtable to return.
* @param bool $addMetadataSubtableId Whether to add the DB subtable ID as metadata
* to each datatable, or not.
* @throws Exception
* @return DataTable|DataTable\Map
*/
- public function getExpandedDataTable($resultIndices, $idSubtable = null, $addMetadataSubtableId = false)
+ public function getExpandedDataTable($resultIndices, $idSubTable = null, $addMetadataSubTableId = false)
{
if ($this->dataType != 'blob') {
throw new Exception("DataCollection: cannot call getExpandedDataTable with "
@@ -248,8 +248,8 @@ class DataCollection
$dataTableFactory = new DataTableFactory(
$this->dataNames, 'blob', $this->sitesId, $this->periods, $this->defaultRow);
- $dataTableFactory->expandDataTable($addMetadataSubtableId);
- $dataTableFactory->useSubtable($idSubtable);
+ $dataTableFactory->expandDataTable($addMetadataSubTableId);
+ $dataTableFactory->useSubtable($idSubTable);
$index = $this->getArray($resultIndices);
return $dataTableFactory->make($index, $resultIndices);
@@ -228,13 +228,13 @@ class DataCollection
*
* Eg, array('site' => 'idSite', 'period' => 'Date')
- * @param int $idSubtable The subtable to return.
- * @param bool $addMetadataSubtableId Whether to add the DB subtable ID as metadata
+ * @param int $idSubTable The subtable to return.
+ * @param bool $addMetadataSubTableId Whether to add the DB subtable ID as metadata
* to each datatable, or not.
* @throws Exception